## 304.0.0.3 (2022-10-31)

pywin32 stubs update (#9040)

boolean methods
win32gui_struct
MonitorFromRect, FindWindow, FindWindowEx, GetWindowPlacement, GetMenuItemRect

## 304.0.0.2 (2022-10-19)

pywin32: Remove IID that doesn't exist at runtime (#8930)

Remove IID that doesn't exist at runtime

## 304.0.0.1 (2022-10-07)

pywin32: Complete modules using stubgen & stubtest (#8866)

Complete modules using stubgen & stubtest

## 304.0.0.0 (2022-10-03)

Add `pywin32` type stubs from microsoft/python-type-stubs and mhammond/pywin32  (#8825)

